@@ -51,9 +51,6 @@ using namespace KAStats;
 using namespace KAStats::Terms;
 
 Backend::Backend(QObject* parent) : QObject(parent)
-    , m_taskManagerItem(0)
-    , m_toolTipItem(0)
-    , m_groupDialog(0)
     , m_panelWinId(0)
     , m_highlightWindows(false)
     , m_actionGroup(new QActionGroup(this))
@@ -314,13 +311,6 @@ QVariantList Backend::recentDocumentActions(const QUrl &launcherUrl, QObject *pa
         | Activity::current()
         | Url::file();
 
-    // Due to KRecentDocument::add() bug, application name "<app>" could
-    // be stored instead of its desktop entry name "org.kde.<app>". Let's
-    // check for both in order to get all results for the application.
-    if (storageId.startsWith(QLatin1String("org.kde."))) {
-        query = query | Agent(storageId.mid(8));
-    }
-
     ResultSet results(query);
 
     ResultSet::const_iterator resultIt = results.begin();
@@ -329,8 +319,6 @@ QVariantList Backend::recentDocumentActions(const QUrl &launcherUrl, QObject *pa
 
     while (actionCount < 5 && resultIt != results.end()) {
         const QString resource = (*resultIt).resource();
-        ++resultIt;
-
         const QUrl url(resource);
 
         if (!url.isValid()) {
@@ -353,6 +341,7 @@ QVariantList Backend::recentDocumentActions(const QUrl &launcherUrl, QObject *pa
 
         actions << QVariant::fromValue<QAction *>(action);
 
+        ++resultIt;
         ++actionCount;
     }
 
@@ -412,13 +401,6 @@ void Backend::handleRecentDocumentAction() const
             | Activity::current()
             | Url::file();
 
-        // Due to KRecentDocument::add() bug, application name "<app>" could
-        // be stored instead of its desktop entry name "org.kde.<app>". Let's
-        // check for both in order to get all results for the application.
-        if (agent.startsWith(QLatin1String("org.kde."))) {
-            query = query | Agent(agent.mid(8));
-        }
-
         KAStats::forgetResources(query);
 
         return;
