@@ -120,8 +120,8 @@ FolderModel::FolderModel(QObject *parent) : QSortFilterProxyModel(parent),
     m_previews(false),
     m_filterMode(NoFilter),
     m_filterPatternMatchAll(true),
-    m_complete(false),
-    m_screenMapper(ScreenMapper::instance())
+    m_screenMapper(ScreenMapper::instance()),
+    m_complete(false)
 {
     //needed to pass the job around with qml
     qmlRegisterType<KIO::DropJob>();
@@ -149,15 +149,11 @@ FolderModel::FolderModel(QObject *parent) : QSortFilterProxyModel(parent),
     m_dirModel->setDirLister(dirLister);
     m_dirModel->setDropsAllowed(KDirModel::DropOnDirectory | KDirModel::DropOnLocalExecutable);
 
-    // If we have dropped items queued for moving, go unsorted now.
-    connect(this, &QAbstractItemModel::rowsAboutToBeInserted,
-            this, [this]() {
-            if (!m_dropTargetPositions.isEmpty()) {
-                setSortMode(-1);
-            }
-    });
-
-    // Position dropped items at the desired target position.
+    /*
+     * position dropped items at the desired target position
+     * delay this via queued connection, such that the row is available and can be mapped
+     * when we emit the move request
+     */
     connect(this, &QAbstractItemModel::rowsInserted,
             this, [this](const QModelIndex &parent, int first, int last) {
         for (int i = first; i <= last; ++i) {
@@ -167,11 +163,11 @@ FolderModel::FolderModel(QObject *parent) : QSortFilterProxyModel(parent),
             if (it != m_dropTargetPositions.end()) {
                 const auto pos = it.value();
                 m_dropTargetPositions.erase(it);
+                setSortMode(-1);
                 emit move(pos.x(), pos.y(), {url});
             }
         }
     });
-
     /*
      * Dropped files may not actually show up as new files, e.g. when we overwrite
      * an existing file. Or files that fail to be listed by the dirLister, or...
@@ -270,7 +266,7 @@ void FolderModel::invalidateFilterIfComplete()
 
 void FolderModel::newFileMenuItemCreated(const QUrl &url)
 {
-    if (m_usedByContainment) {
+    if (m_usedByContainment && !m_screenMapper->sharedDesktops()) {
         m_screenMapper->addMapping(url, m_screen, ScreenMapper::DelayedSignal);
         m_dropTargetPositions.insert(url.fileName(), m_menuPosition);
         m_menuPosition = {};
@@ -326,7 +322,7 @@ void FolderModel::setUrl(const QString& url)
 
     emit iconNameChanged();
 
-    if (m_usedByContainment) {
+    if (m_usedByContainment && !m_screenMapper->sharedDesktops()) {
         m_screenMapper->removeScreen(m_screen, oldUrl);
         m_screenMapper->addScreen(m_screen, resolvedUrl());
     }
@@ -633,7 +629,7 @@ void FolderModel::setScreen(int screen)
         return;
 
     m_screen = screen;
-    if (m_usedByContainment) {
+    if (m_usedByContainment && !m_screenMapper->sharedDesktops()) {
         m_screenMapper->addScreen(screen, resolvedUrl());
     }
     emit screenChanged();
@@ -669,9 +665,8 @@ void FolderModel::cd(int row)
             if (file.hasLinkType()) {
                 setUrl(file.readUrl());
             }
-        }
-        else {
-            setUrl(item.url().toString());
+        } else {
+            setUrl(item.targetUrl().toString());
         }
     }
 }
@@ -1003,8 +998,7 @@ void FolderModel::dragSelectedInternal(int x, int y)
 static bool isDropBetweenSharedViews(const QList<QUrl> &urls, const QUrl &folderUrl)
 {
     for (const auto &url : urls) {
-        if (folderUrl.adjusted(QUrl::StripTrailingSlash)
-               != url.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash)) {
+        if (folderUrl != url.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash)) {
             return false;
         }
     }
@@ -1114,7 +1108,7 @@ void FolderModel::drop(QQuickItem *target, QObject* dropEvent, int row)
     }
 
 
-    if (m_usedByContainment) {
+    if (m_usedByContainment && !m_screenMapper->sharedDesktops()) {
         if (isDropBetweenSharedViews(mimeData->urls(), dropTargetFolderUrl)) {
             setSortMode(-1);
             for (const auto &url : mimeData->urls()) {
@@ -1164,7 +1158,7 @@ void FolderModel::drop(QQuickItem *target, QObject* dropEvent, int row)
             m_dropTargetPositions.insert(targetUrl.fileName(), dropPos);
             m_dropTargetPositionsCleanup->start();
 
-            if (m_usedByContainment) {
+            if (m_usedByContainment && !m_screenMapper->sharedDesktops()) {
                 // assign a screen for the item before the copy is actually done, so
                 // filterAcceptsRow doesn't assign the default screen to it
                 QUrl url = resolvedUrl();
@@ -1273,7 +1267,13 @@ QVariant FolderModel::data(const QModelIndex& index, int role) const
     } else if (role == SelectedRole) {
         return m_selectionModel->isSelected(index);
     } else if (role == IsDirRole) {
-        return isDir(mapToSource(index), m_dirModel);
+        const QUrl &url = data(index, UrlRole).toUrl();
+
+        if (m_isDirCache.contains(url)) {
+            return m_isDirCache[url];
+        } else {
+            return isDir(mapToSource(index), m_dirModel);
+        }
     } else if (role == IsLinkRole) {
         const KFileItem item = itemForIndex(index);
         return item.isLink();
@@ -1293,7 +1293,7 @@ QVariant FolderModel::data(const QModelIndex& index, int role) const
             }
         }
 
-        return item.url();
+        return item.targetUrl();
     } else if (role == SizeRole) {
         bool isDir = data(index, IsDirRole).toBool();
 
@@ -1326,36 +1326,21 @@ bool FolderModel::isDir(const QModelIndex &index, const KDirModel *dirModel) con
         return true;
     }
 
-    auto it = m_isDirCache.constFind(item.url());
-    if (it != m_isDirCache.constEnd()) {
-        return *it;
-    }
-
     if (m_parseDesktopFiles && item.isDesktopFile()) {
         // Check if the desktop file is a link to a directory
         KDesktopFile file(item.targetUrl().path());
 
-        if (!file.hasLinkType()) {
-            return false;
+        if (file.hasLinkType()) {
+            const QUrl url(file.readUrl());
+
+            if (!m_isDirCache.contains(item.url()) && KProtocolInfo::protocolClass(url.scheme()) == QStringLiteral(":local")) {
+                KIO::StatJob *job = KIO::stat(url, KIO::HideProgressInfo);
+                job->setProperty("org.kde.plasma.folder_url", item.url());
+                job->setSide(KIO::StatJob::SourceSide);
+                job->setDetails(0);
+                connect(job, &KJob::result, this, &FolderModel::statResult);
+            }
         }
-
-        const QUrl url(file.readUrl());
-
-        // Check if we already have a running StatJob for this URL.
-        if (m_isDirJobs.contains(item.url())) {
-            return false;
-        }
-
-        if (KProtocolInfo::protocolClass(url.scheme()) != QStringLiteral(":local")) {
-            return false;
-        }
-
-        KIO::StatJob *job = KIO::stat(url, KIO::HideProgressInfo);
-        job->setProperty("org.kde.plasma.folder_url", item.url());
-        job->setSide(KIO::StatJob::SourceSide);
-        job->setDetails(0);
-        connect(job, &KJob::result, this, &FolderModel::statResult);
-        m_isDirJobs.insert(item.url(), job);
     }
 
     return false;
@@ -1365,16 +1350,14 @@ void FolderModel::statResult(KJob *job)
 {
     KIO::StatJob *statJob = static_cast<KIO::StatJob*>(job);
 
-    const QUrl &url = statJob->property("org.kde.plasma.folder_url").value<QUrl>();
+    const QUrl &url = statJob->property("org.kde.plasma.folder_url").toUrl();
     const QModelIndex &idx = index(indexForUrl(url), 0);
 
-    if (idx.isValid() && statJob->error() == KJob::NoError) {
+    if (idx.isValid()) {
         m_isDirCache[url] = statJob->statResult().isDir();
 
         emit dataChanged(idx, idx, QVector<int>() << IsDirRole);
     }
-
-    m_isDirJobs.remove(url);
 }
 
 void FolderModel::evictFromIsDirCache(const KFileItemList& items)
@@ -1505,7 +1488,7 @@ bool FolderModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParen
     const KDirModel *dirModel = static_cast<KDirModel*>(sourceModel());
     const KFileItem item = dirModel->itemForIndex(dirModel->index(sourceRow, KDirModel::Name, sourceParent));
 
-    if (m_usedByContainment) {
+    if (m_usedByContainment && !m_screenMapper->sharedDesktops()) {
         const QUrl url = item.url();
         const int screen = m_screenMapper->screenForItem(url);
         // don't do anything if the folderview is not associated with a screen
@@ -1553,10 +1536,8 @@ void FolderModel::createActions()
     QAction *paste = KStandardAction::paste(this, &FolderModel::paste, this);
     QAction *pasteTo = KStandardAction::paste(this, &FolderModel::pasteTo, this);
 
-    QAction *reload = new QAction(i18n("&Reload"), this);
-    connect(reload, &QAction::triggered, this, &FolderModel::refresh);
-
     QAction *refresh = new QAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18n("&Refresh View"), this);
+    refresh->setShortcut(QKeySequence(QKeySequence::Refresh));
     connect(refresh, &QAction::triggered, this, &FolderModel::refresh);
 
     QAction *rename = KStandardAction::renameFile(this, &FolderModel::requestRename, this);
@@ -1579,7 +1560,6 @@ void FolderModel::createActions()
     m_actionCollection.addAction(QStringLiteral("copy"), copy);
     m_actionCollection.addAction(QStringLiteral("paste"), paste);
     m_actionCollection.addAction(QStringLiteral("pasteto"), pasteTo);
-    m_actionCollection.addAction(QStringLiteral("reload"), reload);
     m_actionCollection.addAction(QStringLiteral("refresh"), refresh);
     m_actionCollection.addAction(QStringLiteral("rename"), rename);
     m_actionCollection.addAction(QStringLiteral("trash"), trash);
@@ -1656,7 +1636,7 @@ void FolderModel::updateActions()
     }
 }
 
-void FolderModel::openContextMenu(QQuickItem *visualParent, Qt::KeyboardModifiers modifiers)
+void FolderModel::openContextMenu(QQuickItem *visualParent)
 {
     QModelIndexList indexes = m_selectionModel->selectedIndexes();
 
@@ -1744,13 +1724,12 @@ void FolderModel::openContextMenu(QQuickItem *visualParent, Qt::KeyboardModifier
                 menu->addAction(emptyTrashAction);
             }
         } else {
-            if (!modifiers.testFlag(Qt::ShiftModifier) && !hasRemoteFiles && itemProperties.supportsMoving()) {
+            if (!hasRemoteFiles && itemProperties.supportsMoving()) {
                 menu->addAction(m_actionCollection.action(QStringLiteral("trash")));
             } else {
                 showDeleteCommand = true;
             }
         }
-
         if (showDeleteCommand && itemProperties.supportsDeleting()) {
             menu->addAction(m_actionCollection.action(QStringLiteral("del")));
         }
@@ -1777,9 +1756,7 @@ void FolderModel::openContextMenu(QQuickItem *visualParent, Qt::KeyboardModifier
         if (KPropertiesDialog::canDisplay(items)) {
             QAction *act = new QAction(menu);
             act->setText(i18n("&Properties"));
-            QObject::connect(act, &QAction::triggered, [this, items]() {
-                    KPropertiesDialog::showDialog(items, nullptr, false /*non modal*/);
-            });
+            QObject::connect(act, &QAction::triggered, this, &FolderModel::openPropertiesDialog);
             menu->addAction(act);
         }
 
@@ -1794,6 +1771,29 @@ void FolderModel::openContextMenu(QQuickItem *visualParent, Qt::KeyboardModifier
     connect(menu, &QMenu::aboutToHide, [menu]() { menu->deleteLater(); });
 }
 
+void FolderModel::openPropertiesDialog()
+{
+    const QModelIndexList indexes = m_selectionModel->selectedIndexes();
+    if (indexes.isEmpty()) {
+        return;
+    }
+
+    KFileItemList items;
+    items.reserve(indexes.count());
+    for (const QModelIndex &index : indexes) {
+        KFileItem item = itemForIndex(index);
+        if (!item.isNull()) {
+            items.append(item);
+        }
+    }
+
+    if (!KPropertiesDialog::canDisplay(items)) {
+        return;
+    }
+
+    KPropertiesDialog::showDialog(items, nullptr, false /*non modal*/);
+}
+
 void FolderModel::linkHere(const QUrl &sourceUrl)
 {
     KIO::CopyJob *job = KIO::link(sourceUrl, m_dirModel->dirLister()->url());
