@@ -55,7 +55,6 @@ class KNewFileMenu;
 
 namespace KIO {
     class DropJob;
-    class StatJob;
 }
 
 class ScreenMapper;
@@ -226,11 +225,12 @@ class FOLDERPLUGIN_TESTS_EXPORT FolderModel : public QSortFilterProxyModel, publ
         Q_INVOKABLE QAction* action(const QString& name) const;
         QObject* newMenu() const;
         Q_INVOKABLE void updateActions();
-        Q_INVOKABLE void openContextMenu(QQuickItem *visualParent = nullptr,
-            Qt::KeyboardModifiers modifiers = Qt::NoModifier);
+        Q_INVOKABLE void openContextMenu(QQuickItem *visualParent = nullptr);
 
         Q_INVOKABLE void linkHere(const QUrl &sourceUrl);
 
+        Q_INVOKABLE void openPropertiesDialog();
+
         QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
         int indexForUrl(const QUrl &url) const;
         KFileItem itemForIndex(const QModelIndex &index) const;
@@ -314,7 +314,6 @@ class FOLDERPLUGIN_TESTS_EXPORT FolderModel : public QSortFilterProxyModel, publ
         KDirWatch *m_dirWatch;
         QString m_url;
         QHash<QUrl, bool> m_isDirCache;
-        mutable QHash<QUrl, KIO::StatJob *> m_isDirJobs;
         QItemSelectionModel *m_selectionModel;
         QItemSelection m_pinnedSelection;
         QModelIndexList m_dragIndexes;
