@@ -20,11 +20,10 @@
 */
 
 #include <unistd.h>
-#include <cmath>
 
 #include "kaccess.h"
 
-#include <QtCore/qprocess.h>
+#include <qprocess.h>
 #include <QTimer>
 #include <QPainter>
 #include <QMessageBox>
@@ -438,14 +437,7 @@ bool KAccessApp::nativeEventFilter(const QByteArray& eventType, void* message, l
         xcb_generic_event_t* event = static_cast<xcb_generic_event_t *>(message);
         if ((event->response_type & ~0x80) == XkbEventCode + xkb_opcode) {
             xkb_any_ *ev = reinterpret_cast<xkb_any_*>(event);
-            // Workaround for an XCB bug. xkbType comes from an EventType that is defined with bits, like
-            // <item name="BellNotify">             <bit>8</bit>
-            // while the generated XCB event type enum is defined as a bitmask, like
-            //     XCB_XKB_EVENT_TYPE_BELL_NOTIFY = 256
-            // This means if xbkType is 8, we need to set the 8th bit to 1, thus raising 2 to power of 8.
-            // See also https://bugs.freedesktop.org/show_bug.cgi?id=51295
-            const int eventType = pow(2, ev->xkbType);
-            switch (eventType) {
+            switch (ev->xkbType) {
                 case XCB_XKB_EVENT_TYPE_STATE_NOTIFY:
                     xkbStateNotify();
                     break;
@@ -526,7 +518,7 @@ void KAccessApp::xkbBellNotify(xcb_xkb_bell_notify_event_t *event)
         WId id = _activeWindow;
 
         NETRect frame, window;
-        NETWinInfo net(QX11Info::connection(), id, qApp->desktop()->winId(), 0);
+        NETWinInfo net(QX11Info::connection(), id, qApp->desktop()->winId(), NET::Properties(), NET::Properties2());
 
         net.kdeGeometry(frame, window);
 
@@ -672,12 +664,14 @@ void KAccessApp::createDialogContents()
         dialog->setObjectName("AccessXWarning");
         dialog->setModal(true);
 
-        QVBoxLayout *topLayout = new QVBoxLayout();
+        QWidget *topcontents = new QWidget(dialog);
+        topcontents->setLayout(new QVBoxLayout(topcontents));
 
-        QHBoxLayout * lay = new QHBoxLayout();
+        QWidget *contents = new QWidget(topcontents);
+        QHBoxLayout * lay = new QHBoxLayout(contents);
 
-        QLabel *label1 = new QLabel();
-        QIcon icon = QIcon::fromTheme(QStringLiteral("dialog-warning"));
+        QLabel *label1 = new QLabel(contents);
+        QIcon icon = QIcon::fromTheme("dialog-warning");
         if (icon.isNull())
             icon = QMessageBox::standardIcon(QMessageBox::Warning);
         label1->setPixmap(icon.pixmap(64, 64));
@@ -687,7 +681,7 @@ void KAccessApp::createDialogContents()
         QVBoxLayout * vlay = new QVBoxLayout();
         lay->addItem(vlay);
 
-        featuresLabel = new QLabel();
+        featuresLabel = new QLabel(QString(), contents);
         featuresLabel->setAlignment(Qt::AlignVCenter);
         featuresLabel->setWordWrap(true);
         vlay->addWidget(featuresLabel);
@@ -696,22 +690,19 @@ void KAccessApp::createDialogContents()
         QHBoxLayout * hlay = new QHBoxLayout();
         vlay->addItem(hlay);
 
-        QLabel *showModeLabel = new QLabel(i18n("&When a gesture was used:"));
+        QLabel *showModeLabel = new QLabel(i18n("&When a gesture was used:"), contents);
         hlay->addWidget(showModeLabel);
 
-        showModeCombobox = new KComboBox();
+        showModeCombobox = new KComboBox(contents);
         hlay->addWidget(showModeCombobox);
         showModeLabel->setBuddy(showModeCombobox);
         showModeCombobox->insertItem(0, i18n("Change Settings Without Asking"));
         showModeCombobox->insertItem(1, i18n("Show This Confirmation Dialog"));
         showModeCombobox->insertItem(2, i18n("Deactivate All AccessX Features & Gestures"));
         showModeCombobox->setCurrentIndex(1);
-        topLayout->addLayout(lay);
 
         auto buttons = new QDialogButtonBox(QDialogButtonBox::Yes | QDialogButtonBox::No, dialog);
-
-        topLayout->addWidget(buttons);
-        dialog->setLayout(topLayout);
+        lay->addWidget(buttons);
 
         connect(buttons, &QDialogButtonBox::accepted, dialog, &QDialog::accept);
         connect(buttons, &QDialogButtonBox::rejected, dialog, &QDialog::reject);
