@@ -105,7 +105,7 @@ ComponentData::ComponentData(
 
 ComponentData::~ComponentData()
     {
-    delete _editor; _editor = 0;
+    delete _editor; _editor = nullptr;
     }
 
 
@@ -133,7 +133,6 @@ public:
 
     KGlobalShortcutsEditorPrivate(KGlobalShortcutsEditor *q)
         :   q(q),
-            stack(0),
             bus(QDBusConnection::sessionBus())
     {}
 
@@ -152,13 +151,13 @@ public:
     KGlobalShortcutsEditor *q;
     Ui::KGlobalShortcutsEditor ui;
     Ui::SelectApplicationDialog selectApplicationDialogUi;
-    QDialog *selectApplicationDialog;
-    QStackedWidget *stack;
+    QDialog *selectApplicationDialog = nullptr;
+    QStackedWidget *stack = nullptr;
     KShortcutsEditor::ActionTypes actionTypes;
     QHash<QString, ComponentData*> components;
     QDBusConnection bus;
-    QStandardItemModel *model;
-    KCategorizedSortFilterProxyModel *proxyModel;
+    QStandardItemModel *model = nullptr;
+    KCategorizedSortFilterProxyModel *proxyModel = nullptr;
 };
 
 void loadAppsCategory(KServiceGroup::Ptr group, QStandardItemModel *model, QStandardItem *item)
@@ -227,13 +226,6 @@ void KGlobalShortcutsEditor::KGlobalShortcutsEditorPrivate::initGUI()
     ui.components->setCategoryDrawer(new KCategoryDrawer(ui.components));
     ui.components->setModelColumn(0);
 
-    // Connect our components
-    connect(ui.components, &QListView::activated,
-            q, [this](const QModelIndex &index) {
-                QString name = proxyModel->data(index).toString();
-                q->activateComponent(name);
-            });
-
     // Build the menu
     QMenu *menu = new QMenu(q);
     menu->addAction( QIcon::fromTheme(QStringLiteral("document-import")), i18n("Import Scheme..."), q, SLOT(importScheme()));
@@ -285,13 +277,13 @@ void KGlobalShortcutsEditor::KGlobalShortcutsEditorPrivate::initGUI()
                         
                         QStringList sequencesStrings = sourceDF.actionGroup(actionId).readEntry(QStringLiteral("X-KDE-Shortcuts"), QString()).split(QChar(','));
                         QList<QKeySequence> sequences;
-                        if (sequencesStrings.length() > 0) {
+                        if (!sequencesStrings.isEmpty()) {
                             Q_FOREACH (const QString &seqString, sequencesStrings) {
                                 sequences.append(QKeySequence(seqString));
                             }
                         }
 
-                        if (sequences.count() > 0) {
+                        if (!sequences.isEmpty()) {
                             KGlobalAccel::self()->setDefaultShortcut(action, sequences);
                         }
                     }
@@ -307,13 +299,13 @@ void KGlobalShortcutsEditor::KGlobalShortcutsEditorPrivate::initGUI()
                         
                         QStringList sequencesStrings = sourceDF.desktopGroup().readEntry(QStringLiteral("X-KDE-Shortcuts"), QString()).split(QChar(','));
                         QList<QKeySequence> sequences;
-                        if (sequencesStrings.length() > 0) {
+                        if (!sequencesStrings.isEmpty()) {
                             Q_FOREACH (const QString &seqString, sequencesStrings) {
                                 sequences.append(QKeySequence(seqString));
                             }
                         }
 
-                        if (sequences.count() > 0) {
+                        if (!sequences.isEmpty()) {
                             KGlobalAccel::self()->setDefaultShortcut(action, sequences);
                         }
                     }
@@ -375,6 +367,13 @@ void KGlobalShortcutsEditor::KGlobalShortcutsEditorPrivate::initGUI()
     proxyModel->setSourceModel(model);
     proxyModel->setSortCaseSensitivity(Qt::CaseInsensitive);
     ui.components->setModel(proxyModel);
+
+    connect(ui.components->selectionModel(),
+        &QItemSelectionModel::currentChanged,
+        q, [this](const QModelIndex &index) {
+            QString name = proxyModel->data(index).toString();
+            q->activateComponent(name);
+        });
 }
 
 
@@ -447,7 +446,7 @@ void KGlobalShortcutsEditor::addCollection(
 
         // Add to the component list
         QStandardItem *item = new QStandardItem(pixmap, friendlyName);
-        if (id.endsWith(QStringLiteral(".desktop"))) {
+        if (id.endsWith(QLatin1String(".desktop"))) {
             item->setData(i18n("Application Launchers"), KCategorizedSortFilterProxyModel::CategoryDisplayRole);
             item->setData(0, KCategorizedSortFilterProxyModel::CategorySortRole);
         } else {
@@ -534,7 +533,7 @@ void KGlobalShortcutsEditor::exportScheme()
         return;
     }
 
-    QUrl url = QFileDialog::getSaveFileUrl(this, QString(), QUrl(), QStringLiteral("*.kksrc"));
+    const QUrl url = QFileDialog::getSaveFileUrl(this, QString(), QUrl(), QStringLiteral("*.kksrc"));
     if (!url.isEmpty()) {
         KConfig config(url.path(), KConfig::SimpleConfig);
         // TODO: Bug ossi to provide a method for this
@@ -833,7 +832,7 @@ void KGlobalShortcutsEditor::KGlobalShortcutsEditorPrivate::removeComponent(
             {
             // Remove from QComboBox
             QModelIndexList results = proxyModel->match(proxyModel->index(0, 0), Qt::DisplayRole, text);
-            Q_ASSERT(results.isEmpty());
+            Q_ASSERT(!results.isEmpty());
             model->removeRow(proxyModel->mapToSource(results.first()).row());
 
             // Remove from QStackedWidget
