@@ -53,6 +53,7 @@ public:
         PluginNameRole = Qt::UserRole +1,
         ScreenhotRole,
         FullScreenPreviewRole,
+        DescriptionRole,
         HasSplashRole,
         HasLockScreenRole,
         HasRunCommandRole,
@@ -68,7 +69,8 @@ public:
     KCMLookandFeel(QObject* parent, const QVariantList& args);
     ~KCMLookandFeel();
 
-    QList<Plasma::Package> availablePackages(const QString &component = QString());
+    //List only packages which provide at least one of the components
+    QList<Plasma::Package> availablePackages(const QStringList &components);
 
     QStandardItemModel *lookAndFeelModel();
 
@@ -104,12 +106,14 @@ public:
     bool resetDefaultLayout() const;
     void setResetDefaultLayout(bool reset);
 
+    void loadModel();
+
     Q_INVOKABLE void getNewStuff();
 
 public Q_SLOTS:
-    void load() Q_DECL_OVERRIDE;
-    void save() Q_DECL_OVERRIDE;
-    void defaults() Q_DECL_OVERRIDE;
+    void load() override;
+    void save() override;
+    void defaults() override;
 
 Q_SIGNALS:
     void selectedPluginChanged();
